@@ -12,41 +12,60 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_log import log as logging
 from webob import exc
 
 from murano.api.v1 import request_statistics
-from murano.common.i18n import _
 from murano.common import wsgi
 from murano.db import models
 from murano.db.services import environments as envs
 from murano.db.services import sessions
 from murano.db import session as db_session
-from murano.services import states
-from murano.utils import check_env
-from murano.utils import check_session
+
+from murano.openstack.common.gettextutils import _  # noqa
+from murano.openstack.common import log as logging
 
 LOG = logging.getLogger(__name__)
 API_NAME = 'Sessions'
 
 
 class Controller(object):
+    def _check_session(self, environment_id, session, session_id):
+        if session is None:
+            msg = _('Session <SessionId {0}> is not found').format(session_id)
+            LOG.error(msg)
+            raise exc.HTTPNotFound(explanation=msg)
+
+        if session.environment_id != environment_id:
+            msg = _('Session <SessionId {0}> is not tied with Environment '
+                    '<EnvId {1}>').format(session_id, environment_id)
+            LOG.error(msg)
+            raise exc.HTTPNotFound(explanation=msg)
 
     @request_statistics.stats_count(API_NAME, 'Create')
     def configure(self, request, environment_id):
-        LOG.debug('Session:Configure <EnvId: {env_id}>'
-                  .format(env_id=environment_id))
+        LOG.debug('Session:Configure <EnvId: {0}>'.format(environment_id))
 
-        check_env(request, environment_id)
+        unit = db_session.get_session()
+        environment = unit.query(models.Environment).get(environment_id)
 
-        # No new session can be opened if environment has deploying or
-        # deleting status.
+        if environment is None:
+            msg = _('Environment <EnvId {0}>'
+                    ' is not found').format(environment_id)
+            LOG.error(msg)
+            raise exc.HTTPNotFound(explanation=msg)
+
+        if environment.tenant_id != request.context.tenant:
+            msg = _('User is not authorized to access '
+                    'this tenant resources.')
+            LOG.error(msg)
+            raise exc.HTTPUnauthorized(explanation=msg)
+
+        # no new session can be opened if environment has deploying status
         env_status = envs.EnvironmentServices.get_status(environment_id)
-        if env_status in (states.EnvironmentStatus.DEPLOYING,
-                          states.EnvironmentStatus.DELETING):
-            msg = _('Could not open session for environment <EnvId: '
-                    '{env_id}>, environment has deploying or '
-                    'deleting status.').format(env_id=environment_id)
+        if env_status in (envs.EnvironmentStatus.DEPLOYING,
+                          envs.EnvironmentStatus.DELETING):
+            msg = _('Could not open session for environment <EnvId: {0}>,'
+                    'environment has deploying status.').format(environment_id)
             LOG.error(msg)
             raise exc.HTTPForbidden(explanation=msg)
 
@@ -57,26 +76,22 @@ class Controller(object):
 
     @request_statistics.stats_count(API_NAME, 'Index')
     def show(self, request, environment_id, session_id):
-        LOG.debug('Session:Show <SessionId: {id}>'.format(id=session_id))
+        LOG.debug('Session:Show <SessionId: {0}>'.format(session_id))
 
         unit = db_session.get_session()
         session = unit.query(models.Session).get(session_id)
 
-        check_session(request, environment_id, session, session_id)
+        self._check_session(environment_id, session, session_id)
 
         user_id = request.context.user
-
+        msg = _('User <UserId {0}> is not authorized to access session'
+                '<SessionId {1}>.').format(user_id, session_id)
         if session.user_id != user_id:
-            msg = _('User <UserId {usr_id}> is not authorized to access '
-                    'session <SessionId {s_id}>.').format(usr_id=user_id,
-                                                          s_id=session_id)
             LOG.error(msg)
             raise exc.HTTPUnauthorized(explanation=msg)
 
         if not sessions.SessionServices.validate(session):
-            msg = _('Session <SessionId {0}> is invalid: environment has been '
-                    'updated or updating right now with other session'
-                    ).format(session_id)
+            msg = _('Session <SessionId {0}> is invalid').format(session_id)
             LOG.error(msg)
             raise exc.HTTPForbidden(explanation=msg)
 
@@ -84,24 +99,23 @@ class Controller(object):
 
     @request_statistics.stats_count(API_NAME, 'Delete')
     def delete(self, request, environment_id, session_id):
-        LOG.debug('Session:Delete <SessionId: {s_id}>'.format(s_id=session_id))
+        LOG.debug('Session:Delete <SessionId: {0}>'.format(session_id))
 
         unit = db_session.get_session()
         session = unit.query(models.Session).get(session_id)
 
-        check_session(request, environment_id, session, session_id)
+        self._check_session(environment_id, session, session_id)
 
         user_id = request.context.user
         if session.user_id != user_id:
-            msg = _('User <UserId {usr_id}> is not authorized to access '
-                    'session <SessionId {s_id}>.').format(usr_id=user_id,
-                                                          s_id=session_id)
+            msg = _('User <UserId {0}> is not authorized to access session'
+                    '<SessionId {1}>.').format(user_id, session_id)
             LOG.error(msg)
             raise exc.HTTPUnauthorized(explanation=msg)
 
-        if session.state == states.SessionState.DEPLOYING:
-            msg = _('Session <SessionId: {s_id}> is in deploying state '
-                    'and could not be deleted').format(s_id=session_id)
+        if session.state == sessions.SessionState.DEPLOYING:
+            msg = _('Session <SessionId: {0}> is in deploying state and '
+                    'could not be deleted').format(session_id)
             LOG.error(msg)
             raise exc.HTTPForbidden(explanation=msg)
 
@@ -112,29 +126,27 @@ class Controller(object):
 
     @request_statistics.stats_count(API_NAME, 'Deploy')
     def deploy(self, request, environment_id, session_id):
-        LOG.debug('Session:Deploy <SessionId: {s_id}>'.format(s_id=session_id))
+        LOG.debug('Session:Deploy <SessionId: {0}>'.format(session_id))
 
         unit = db_session.get_session()
         session = unit.query(models.Session).get(session_id)
 
-        check_session(request, environment_id, session, session_id)
+        self._check_session(environment_id, session, session_id)
 
         if not sessions.SessionServices.validate(session):
-            msg = _('Session <SessionId {0}> is invalid: environment has been '
-                    'updated or updating right now with other session'
-                    ).format(session_id)
+            msg = _('Session <SessionId {0}> is invalid').format(session_id)
             LOG.error(msg)
             raise exc.HTTPForbidden(explanation=msg)
 
-        if session.state != states.SessionState.OPENED:
-            msg = _('Session <SessionId {s_id}> is already deployed or '
-                    'deployment is in progress').format(s_id=session_id)
+        if session.state != sessions.SessionState.OPENED:
+            msg = _('Session <SessionId {0}> is already deployed or '
+                    'deployment is in progress').format(session_id)
             LOG.error(msg)
             raise exc.HTTPForbidden(explanation=msg)
 
         envs.EnvironmentServices.deploy(session,
                                         unit,
-                                        request.context)
+                                        request.context.auth_token)
 
 
 def create_resource():
