@@ -14,25 +14,25 @@
 
 import collections
 import functools as func
-import re
+import types
 
+import eventlet
 import jsonschema
-from oslo_log import log as logging
 
-from murano.common.i18n import _
+from murano.openstack.common.gettextutils import _  # noqa
+from murano.openstack.common import log as logging
 
 
 LOG = logging.getLogger(__name__)
 
 
 class TraverseHelper(object):
-    value_type = (str, int, float, bool)
+    value_type = (types.StringTypes, types.IntType, types.FloatType,
+                  types.BooleanType)
 
     @staticmethod
     def get(path, source):
-        """Provides the ability to traverse a data source
-
-        Provides the ability to traverse a data source made up of any
+        """Provides the ability to traverse a data source made up of any
         combination of lists and dicts. Has simple rules for selecting item of
         the list:
 
@@ -60,7 +60,7 @@ class TraverseHelper(object):
         while len(queue):
             path = queue.popleft()
 
-            if isinstance(source, list):
+            if isinstance(source, types.ListType):
                 idx_source = source
                 iterator = (
                     i for i in source
@@ -69,7 +69,7 @@ class TraverseHelper(object):
                 source = next(iterator, None)
                 if source is None and path.isdigit():
                     source = idx_source[int(path)]
-            elif isinstance(source, dict):
+            elif isinstance(source, types.DictionaryType):
                 source = source[path]
             elif isinstance(source, TraverseHelper.value_type):
                 break
@@ -91,10 +91,7 @@ class TraverseHelper(object):
         parent_path = '/'.join(path.split('/')[:-1])
         node = TraverseHelper.get(parent_path, source)
         key = path[1:].split('/')[-1]
-        if is_number(key):
-            node[int(key)] = value
-        else:
-            node[key] = value
+        node[key] = value
 
     @staticmethod
     def insert(path, value, source):
@@ -129,27 +126,19 @@ class TraverseHelper(object):
         node = TraverseHelper.get(parent_path, source)
         key = path[1:].split('/')[-1]
 
-        if isinstance(node, list):
+        if isinstance(node, types.ListType):
             iterator = (i for i in node if i.get('?', {}).get('id') == key)
             item = next(iterator, None)
             if item is None and key.isdigit():
                 del node[int(key)]
             else:
                 node.remove(item)
-        elif isinstance(node, dict):
+        elif isinstance(node, types.DictionaryType):
             del node[key]
         else:
             raise ValueError(_('Source object or path is malformed'))
 
 
-def is_number(var):
-    try:
-        int(var)
-        return True
-    except Exception:
-        return False
-
-
 def is_different(obj1, obj2):
     """Stripped-down version of deep.diff comparator
 
@@ -177,8 +166,8 @@ def is_different(obj1, obj2):
 
         if o1 is o2:
             return
-        elif (isinstance(o1, str) and
-                isinstance(o2, str)) and o1 == o2:
+        elif (isinstance(o1, basestring)
+              and isinstance(o2, basestring)) and o1 == o2:
             return
         elif type(o1) != type(o2):
             raise Difference()
@@ -208,12 +197,12 @@ def is_different(obj1, obj2):
 
 def build_entity_map(value):
     def build_entity_map_recursive(value, id_map):
-        if isinstance(value, dict):
+        if isinstance(value, types.DictionaryType):
             if '?' in value and 'id' in value['?']:
                 id_map[value['?']['id']] = value
-            for v in value.values():
+            for k, v in value.iteritems():
                 build_entity_map_recursive(v, id_map)
-        if isinstance(value, list):
+        if isinstance(value, types.ListType):
             for item in value:
                 build_entity_map_recursive(item, id_map)
 
@@ -222,6 +211,51 @@ def build_entity_map(value):
     return id_map
 
 
+def retry(ExceptionToCheck, tries=4, delay=3, backoff=2):
+    """Retry calling the decorated function using an exponential backoff.
+
+    http://www.saltycrane.com/blog/2009/11/trying-out-retry-decorator-python/
+    original from: http://wiki.python.org/moin/PythonDecoratorLibrary#Retry
+
+    :param ExceptionToCheck: the exception to check. may be a tuple of
+        exceptions to check
+    :type ExceptionToCheck: Exception or tuple
+    :param tries: number of times to try (not retry) before giving up
+    :type tries: int
+    :param delay: initial delay between retries in seconds
+    :type delay: int
+    :param backoff: backoff multiplier e.g. value of 2 will double the delay
+        each retry
+    :type backoff: int
+    """
+
+    def deco_retry(f):
+        @func.wraps(f)
+        def f_retry(*args, **kwargs):
+            mtries, mdelay = tries, delay
+            forever = mtries == -1
+            while forever or mtries > 1:
+                try:
+                    return f(*args, **kwargs)
+                except ExceptionToCheck as e:
+
+                    LOG.exception(e)
+                    LOG.info(_("Retrying in {0} seconds...").format(mdelay))
+
+                    eventlet.sleep(mdelay)
+
+                    if not forever:
+                        mtries -= 1
+
+                    if mdelay < 60:
+                        mdelay *= backoff
+            return f(*args, **kwargs)
+
+        return f_retry
+
+    return deco_retry
+
+
 def handle(f):
     """Handles exception in wrapped function and writes to LOG."""
 
@@ -244,69 +278,3 @@ def validate_body(schema):
                 return f(*args, **kwargs)
         return f_validate_body
     return deco_validate_body
-
-
-def validate_quotes(value):
-    """Validate filter values
-
-    Validation opening/closing quotes in the expression.
-    """
-    open_quotes = True
-    count_backslash_in_row = 0
-    for i in range(len(value)):
-        if value[i] == '"':
-            if count_backslash_in_row % 2:
-                continue
-            if open_quotes:
-                if i and value[i - 1] != ',':
-                    msg = _("Invalid filter value %s. There is no comma "
-                            "before opening quotation mark.") % value
-                    raise ValueError(msg)
-            else:
-                if i + 1 != len(value) and value[i + 1] != ",":
-                    msg = _("Invalid filter value %s. There is no comma "
-                            "after opening quotation mark.") % value
-                    raise ValueError(msg)
-            open_quotes = not open_quotes
-        elif value[i] == '\\':
-            count_backslash_in_row += 1
-        else:
-            count_backslash_in_row = 0
-    if not open_quotes:
-        msg = _("Invalid filter value %s. The quote is not closed.") % value
-        raise ValueError(msg)
-    return True
-
-
-def split_for_quotes(value):
-    """Split filter values
-
-    Split values by commas and quotes for 'in' operator, according api-wg.
-    """
-    validate_quotes(value)
-    tmp = re.compile(r'''
-        "(                 # if found a double-quote
-           [^\"\\]*        # take characters either non-quotes or backslashes
-           (?:\\.          # take backslashes and character after it
-            [^\"\\]*)*     # take characters either non-quotes or backslashes
-         )                 # before double-quote
-        ",?                # a double-quote with comma maybe
-        | ([^,]+),?        # if not found double-quote take any non-comma
-                           # characters with comma maybe
-        | ,                # if we have only comma take empty string
-        ''', re.VERBOSE)
-    val_split = [val[0] or val[1] for val in re.findall(tmp, value)]
-    replaced_inner_quotes = [s.replace(r'\"', '"') for s in val_split]
-    return replaced_inner_quotes
-
-
-def reraise(tp, value, tb=None):
-    try:
-        if value is None:
-            value = tp()
-        if value.__traceback__ is not tb:
-            raise value.with_traceback(tb)
-        raise value
-    finally:
-        value = None
-        tb = None
