@@ -15,55 +15,50 @@
 import inspect
 import os.path
 
-from yaql import specs
-
-from murano.dsl import constants
-from murano.dsl import dsl
-from murano.dsl import dsl_types
 from murano.dsl import helpers
-from murano.dsl import yaql_integration
+from murano.dsl import murano_class
+from murano.dsl import murano_object
+from murano.dsl import yaql_expression
 
 
-@dsl.name('io.murano.StackTrace')
-class StackTrace(object):
-    def __init__(self, this, context, include_native_frames=True):
+@murano_class.classname('io.murano.StackTrace')
+class StackTrace(murano_object.MuranoObject):
+
+    def initialize(self, _context, includeNativeFrames=True):
         frames = []
-        caller_context = context
+        context = _context
         while True:
-            if not caller_context:
+            if not context:
                 break
-            frame = compose_stack_frame(caller_context)
-            frames.append(frame)
-            caller_context = helpers.get_caller_context(caller_context)
-        frames.reverse()
+            frames.append(compose_stack_frame(context))
+            context = helpers.get_caller_context(context)
         frames.pop()
+        frames.reverse()
 
-        if include_native_frames:
+        if includeNativeFrames:
             native_frames = []
             for frame in inspect.trace()[1:]:
-                location = dsl_types.ExpressionFilePosition(
+                location = yaql_expression.YaqlExpressionFilePosition(
                     os.path.abspath(frame[1]), frame[2],
-                    -1, frame[2], -1)
+                    -1, -1, -1, -1, -1)
                 method = frame[3]
                 native_frames.append({
                     'instruction': frame[4][0].strip(),
                     'location': location,
-                    'methodName': method,
-                    'typeName': None
+                    'method': method,
+                    'class': None
                 })
             frames.extend(native_frames)
 
-        this.properties.frames = frames
+        self.set_property('frames', frames)
 
-    @specs.meta(constants.META_NO_TRACE, True)
-    @specs.meta('Usage', 'Action')
-    def to_string(self, this, prefix=''):
-        return '\n'.join([format_frame(t, prefix)for t in this['frames']])
+    def toString(self, prefix=''):
+        return '\n'.join([format_frame(t, prefix)for t in self.get_property(
+            'frames')])
 
 
 def compose_stack_frame(context):
     instruction = helpers.get_current_instruction(context)
-    method = helpers.get_current_method(context)
     return {
         'instruction': None if instruction is None
         else str(instruction),
@@ -71,18 +66,18 @@ def compose_stack_frame(context):
         'location': None if instruction is None
         else instruction.source_file_position,
 
-        'methodName': None if method is None else method.name,
-        'typeName': None if method is None else method.declaring_type.name
+        'method': helpers.get_current_method(context),
+        'class': helpers.get_type(context)
     }
 
 
 def format_frame(frame, prefix=''):
     instruction = frame['instruction']
-    method_name = frame['methodName']
-    type_name = frame['typeName']
+    method = frame['method']
+    murano_class = frame['class']
     location = frame['location']
-    if type_name:
-        method_name += ' of type ' + type_name
+    if murano_class:
+        method += ' of class ' + murano_class.name
 
     if location:
         args = (
@@ -90,19 +85,12 @@ def format_frame(frame, prefix=''):
             location.start_line,
             ':' + str(location.start_column)
             if location.start_column >= 0 else '',
-            method_name,
+            method,
             instruction,
             prefix
         )
-        return (u'{5}File "{0}", line {1}{2} in method {3}\n'
-                u'{5}    {4}').format(*args)
+        return '{5}File "{0}", line {1}{2} in method {3}\n' \
+               '{5}    {4}'.format(*args)
     else:
-        return u'{2}File <unknown> in method {0}\n{2}    {1}'.format(
-            method_name, instruction, prefix)
-
-
-def create_stack_trace(context, include_native_frames=True):
-    stacktrace = yaql_integration.call_func(
-        context, 'new', 'io.murano.StackTrace',
-        includeNativeFrames=include_native_frames)
-    return dsl.MuranoObjectInterface.create(stacktrace)
+        return '{2}File <unknown> in method {0}\n{2}    {1}'.format(
+            method, instruction, prefix)
