@@ -13,85 +13,69 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import greenlet
-from oslo_config import cfg
-from oslo_log import log as logging
+import eventlet
 
-from murano.common import exceptions
-from murano.dsl import dsl
-from murano.engine.system import common
+import murano.common.config as config
+import murano.dsl.murano_class as murano_class
+import murano.dsl.murano_object as murano_object
+import murano.engine.system.common as common
+
+from murano.openstack.common import log as logging
 
 LOG = logging.getLogger(__name__)
-CONF = cfg.CONF
 
 
 class AgentListenerException(Exception):
     pass
 
 
-@dsl.name('io.murano.system.AgentListener')
-class AgentListener(object):
-    def __init__(self, name):
-        self._enabled = not CONF.engine.disable_murano_agent
+@murano_class.classname('io.murano.system.AgentListener')
+class AgentListener(murano_object.MuranoObject):
+    def initialize(self, _context, name):
+        self._enabled = False
+        if config.CONF.engine.disable_murano_agent:
+            return
+        self._enabled = True
         self._results_queue = str('-execution-results-%s' % name.lower())
         self._subscriptions = {}
         self._receive_thread = None
 
-    def _check_enabled(self):
-        if CONF.engine.disable_murano_agent:
-            LOG.error('Use of murano-agent is disallowed '
-                      'by the server configuration')
-
-            raise exceptions.PolicyViolationException(
-                'Use of murano-agent is disallowed '
-                'by the server configuration')
-
     @property
     def enabled(self):
         return self._enabled
 
-    def queue_name(self):
+    def queueName(self):
         return self._results_queue
 
     def start(self):
-        if CONF.engine.disable_murano_agent:
+        if config.CONF.engine.disable_murano_agent:
             # Noop
             LOG.debug("murano-agent is disabled by the server")
             return
 
         if self._receive_thread is None:
-            dsl.get_execution_session().on_session_finish(
-                lambda: self.stop())
-            self._receive_thread = dsl.spawn(
-                self._receive,
-                dsl.get_this().find_owner('io.murano.CloudRegion'))
+            self._receive_thread = eventlet.spawn(self._receive)
 
     def stop(self):
-        if CONF.engine.disable_murano_agent:
+        if config.CONF.engine.disable_murano_agent:
             # Noop
             LOG.debug("murano-agent is disabled by the server")
             return
 
         if self._receive_thread is not None:
             self._receive_thread.kill()
-            try:
-                self._receive_thread.wait()
-            except greenlet.GreenletExit:
-                pass
-            finally:
-                self._receive_thread = None
+            self._receive_thread = None
 
     def subscribe(self, message_id, event):
-        self._check_enabled()
+        if config.CONF.engine.disable_murano_agent:
+            raise AgentListenerException(
+                "Use of murano-agent is disallowed "
+                "by the server configuration")
+
         self._subscriptions[message_id] = event
-        self.start()
 
-    def unsubscribe(self, message_id):
-        self._check_enabled()
-        self._subscriptions.pop(message_id)
-
-    def _receive(self, region):
-        with common.create_rmq_client(region) as client:
+    def _receive(self):
+        with common.create_rmq_client() as client:
             client.declare(self._results_queue, enable_ha=True, ttl=86400000)
             with client.open(self._results_queue) as subscription:
                 while True:
@@ -100,9 +84,8 @@ class AgentListener(object):
                         continue
                     msg.ack()
                     msg_id = msg.body.get('SourceID', msg.id)
-                    LOG.debug("Got execution result: id '{msg_id}'"
-                              " body '{body}'".format(msg_id=msg_id,
-                                                      body=msg.body))
+                    LOG.debug("Got execution result: id '{0}'"
+                              " body '{1}'".format(msg_id, msg.body))
                     if msg_id in self._subscriptions:
                         event = self._subscriptions.pop(msg_id)
                         event.send(msg.body)
