@@ -14,72 +14,77 @@
 # limitations under the License.
 import math
 
+import keystoneclient.apiclient.exceptions as ks_exc
+import keystoneclient.v2_0.client as ksclient
 import netaddr
 from netaddr.strategy import ipv4
 import neutronclient.v2_0.client as nclient
-from oslo_config import cfg
-from oslo_log import log as logging
-from oslo_utils import uuidutils
-import tenacity
 
-from murano.common import auth_utils
-from murano.common import exceptions as exc
-from murano.dsl import dsl
-from murano.dsl import helpers
-from murano.dsl import session_local_storage
+import murano.common.config as config
+import murano.dsl.helpers as helpers
+import murano.dsl.murano_class as murano_class
+import murano.dsl.murano_object as murano_object
+from murano.openstack.common import log as logging
+import muranoclient.openstack.common.uuidutils as uuidutils
+
 
-CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 
-@dsl.name('io.murano.system.NetworkExplorer')
-class NetworkExplorer(object):
-    def __init__(self, this, region_name=None):
-        session = helpers.get_execution_session()
-        self._project_id = session.project_id
-        self._settings = CONF.networking
+@murano_class.classname('io.murano.system.NetworkExplorer')
+class NetworkExplorer(murano_object.MuranoObject):
+    # noinspection PyAttributeOutsideInit
+    def initialize(self, _context):
+        environment = helpers.get_environment(_context)
+        self._tenant_id = environment.tenant_id
+        keystone_settings = config.CONF.keystone
+        neutron_settings = config.CONF.neutron
+        self._settings = config.CONF.networking
+
+        keystone_client = ksclient.Client(
+            endpoint=keystone_settings.auth_url,
+            cacert=keystone_settings.ca_file or None,
+            cert=keystone_settings.cert_file or None,
+            key=keystone_settings.key_file or None,
+            insecure=keystone_settings.insecure)
+
+        if not keystone_client.authenticate(
+                auth_url=keystone_settings.auth_url,
+                tenant_id=environment.tenant_id,
+                token=environment.token):
+            raise ks_exc.AuthorizationFailure()
+
+        neutron_url = keystone_client.service_catalog.url_for(
+            service_type='network',
+            endpoint_type=neutron_settings.endpoint_type)
+
+        self._neutron = \
+            nclient.Client(endpoint_url=neutron_url,
+                           token=environment.token,
+                           ca_cert=neutron_settings.ca_cert or None,
+                           insecure=neutron_settings.insecure)
+
         self._available_cidrs = self._generate_possible_cidrs()
-        self._region = this.find_owner('io.murano.CloudRegion')
-        self._region_name = region_name
 
-    @staticmethod
-    @session_local_storage.execution_session_memoize
-    def _get_client(region_name):
-        return nclient.Client(**auth_utils.get_session_client_parameters(
-            service_type='network', region=region_name, conf='neutron'
-        ))
-
-    @property
-    def _client(self):
-        region = self._region_name or (
-            None if self._region is None else self._region['name'])
-        return self._get_client(region)
-
-    # NOTE(starodubcevna): to avoid simultaneous router requests we use retry
-    # decorator with random delay 1-10 seconds between attempts and maximum
-    # delay time 30 seconds.
-    @tenacity.retry(
-        retry=tenacity.retry_if_exception_type(exc.RouterInfoException),
-        stop=tenacity.stop_after_delay(30),
-        wait=tenacity.wait_random(min=1, max=10),
-        reraise=True)
-    def get_default_router(self):
+    # noinspection PyPep8Naming
+    def getDefaultRouter(self):
         router_name = self._settings.router_name
 
-        routers = self._client.list_routers(
-            tenant_id=self._project_id, name=router_name).get('routers')
+        routers = self._neutron.\
+            list_routers(tenant_id=self._tenant_id, name=router_name).\
+            get('routers')
         if len(routers) == 0:
-            LOG.debug('Router {name} not found'.format(name=router_name))
+            LOG.debug('Router {0} not found'.format(router_name))
             if self._settings.create_router:
-                LOG.debug('Attempting to create Router {router}'.
-                          format(router=router_name))
+                LOG.debug('Attempting to create Router {0}'.
+                          format(router_name))
                 external_network = self._settings.external_network
                 kwargs = {'id': external_network} \
                     if uuidutils.is_uuid_like(external_network) \
                     else {'name': external_network}
-                networks = self._client.list_networks(**kwargs).get('networks')
-                ext_nets = list(filter(lambda n: n['router:external'],
-                                       networks))
+                networks = self._neutron.list_networks(**kwargs). \
+                    get('networks')
+                ext_nets = filter(lambda n: n['router:external'], networks)
                 if len(ext_nets) == 0:
                     raise KeyError('Router %s could not be created, '
                                    'no external network found' % router_name)
@@ -94,28 +99,28 @@ class NetworkExplorer(object):
                         'admin_state_up': True,
                     }
                 }
-                router = self._client.create_router(
-                    body=body_data).get('router')
-                LOG.info('Created router: {id}'.format(id=router['id']))
+                router = self._neutron.create_router(body=body_data).\
+                    get('router')
+                LOG.debug('Created router: {0}'.format(router))
                 return router['id']
             else:
                 raise KeyError('Router %s was not found' % router_name)
         else:
             if routers[0]['external_gateway_info'] is None:
-                raise exc.RouterInfoException('Please set external gateway for'
-                                              ' the router %s ' % router_name)
+                raise Exception('Please set external gateway '
+                                'for the router %s ' % router_name)
             router_id = routers[0]['id']
         return router_id
 
-    def get_available_cidr(self, router_id, net_id):
-        """Uses hash of network IDs to minimize the collisions
-
-        Different nets will attempt to pick different cidrs out of available
+    # noinspection PyPep8Naming
+    def getAvailableCidr(self, routerId, netId):
+        """Uses hash of network IDs to minimize the collisions:
+        different nets will attempt to pick different cidrs out of available
         range.
-        If the cidr is taken will pick another one.
+        If the cidr is taken will pick another one
         """
-        taken_cidrs = self._get_cidrs_taken_by_router(router_id)
-        id_hash = hash(net_id)
+        taken_cidrs = self._get_cidrs_taken_by_router(routerId)
+        id_hash = hash(netId)
         num_fails = 0
         while num_fails < len(self._available_cidrs):
             cidr = self._available_cidrs[
@@ -127,29 +132,32 @@ class NetworkExplorer(object):
                 return str(cidr)
         return None
 
-    def get_default_dns(self):
+    # noinspection PyPep8Naming
+    def getDefaultDns(self):
         return self._settings.default_dns
 
-    def get_external_network_id_for_router(self, router_id):
-        router = self._client.show_router(router_id).get('router')
+    # noinspection PyPep8Naming
+    def getExternalNetworkIdForRouter(self, routerId):
+        router = self._neutron.show_router(routerId).get('router')
         if not router or 'external_gateway_info' not in router:
             return None
         return router['external_gateway_info'].get('network_id')
 
-    def get_external_network_id_for_network(self, network_id):
-        network = self._client.show_network(network_id).get('network')
+    # noinspection PyPep8Naming
+    def getExternalNetworkIdForNetwork(self, networkId):
+        network = self._neutron.show_network(networkId).get('network')
         if network.get('router:external', False):
-            return network_id
+            return networkId
 
         # Get router interfaces of the network
-        router_ports = self._client.list_ports(
+        router_ports = self._neutron.list_ports(
             **{'device_owner': 'network:router_interface',
-               'network_id': network_id}).get('ports')
+               'network_id': networkId}).get('ports')
 
         # For each router this network is connected to
         # check if the router has external_gateway set
         for router_port in router_ports:
-            ext_net_id = self.get_external_network_id_for_router(
+            ext_net_id = self.getExternalNetworkIdForRouter(
                 router_port.get('device_id'))
             if ext_net_id:
                 return ext_net_id
@@ -158,13 +166,13 @@ class NetworkExplorer(object):
     def _get_cidrs_taken_by_router(self, router_id):
         if not router_id:
             return []
-        ports = self._client.list_ports(device_id=router_id)['ports']
+        ports = self._neutron.list_ports(device_id=router_id)['ports']
         subnet_ids = []
         for port in ports:
             for fixed_ip in port['fixed_ips']:
                 subnet_ids.append(fixed_ip['subnet_id'])
 
-        all_subnets = self._client.list_subnets()['subnets']
+        all_subnets = self._neutron.list_subnets()['subnets']
         filtered_cidrs = [netaddr.IPNetwork(subnet['cidr']) for subnet in
                           all_subnets if subnet['id'] in subnet_ids]
 
@@ -183,15 +191,3 @@ class NetworkExplorer(object):
         net = netaddr.IPNetwork(
             '{0}/{1}'.format(self._settings.env_ip_template, mask_width))
         return list(net.subnet(width - bits_for_hosts))
-
-    def list_networks(self):
-        return self._client.list_networks()['networks']
-
-    def list_subnetworks(self):
-        return self._client.list_subnets()['subnets']
-
-    def list_ports(self):
-        return self._client.list_ports()['ports']
-
-    def list_neutron_extensions(self):
-        return self._client.list_extensions()['extensions']
