@@ -12,17 +12,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from nose.plugins.attrib import attr as tag
-from tempest.lib import exceptions
+from tempest import exceptions
 from tempest.test import attr
-import testtools
 
 from murano.tests.functional.api import base
 
 
 class TestSessions(base.TestCase):
 
-    @tag('all', 'coverage')
     @attr(type='smoke')
     def test_create_session(self):
         env = self.create_environment('test')
@@ -32,14 +29,12 @@ class TestSessions(base.TestCase):
         self.assertEqual(resp.status, 200)
         self.assertEqual(env['id'], sess['environment_id'])
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_create_session_before_env(self):
         self.assertRaises(exceptions.NotFound,
                           self.client.create_session,
                           None)
 
-    @tag('all', 'coverage')
     @attr(type='smoke')
     def test_delete_session(self):
         env = self.create_environment('test')
@@ -50,19 +45,17 @@ class TestSessions(base.TestCase):
 
         self.assertEqual(resp.status, 200)
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_delete_session_without_env_id(self):
         env = self.create_environment('test')
 
         sess = self.client.create_session(env['id'])[1]
 
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(exceptions.NotFound,
                           self.client.delete_session,
                           None,
                           sess['id'])
 
-    @tag('all', 'coverage')
     @attr(type='smoke')
     def test_get_session(self):
         env = self.create_environment('test')
@@ -74,19 +67,17 @@ class TestSessions(base.TestCase):
         self.assertEqual(resp.status, 200)
         self.assertEqual(session, sess)
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_get_session_without_env_id(self):
         env = self.create_environment('test')
 
         sess = self.client.create_session(env['id'])[1]
 
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(exceptions.NotFound,
                           self.client.get_session,
                           None,
                           sess['id'])
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_get_session_after_delete_env(self):
         env = self.create_environment('test')
@@ -100,7 +91,6 @@ class TestSessions(base.TestCase):
                           env['id'],
                           sess['id'])
 
-    @tag('all', 'coverage')
     @attr(type='negative')
     def test_double_delete_session(self):
         env = self.create_environment('test')
@@ -113,45 +103,3 @@ class TestSessions(base.TestCase):
                           self.client.delete_session,
                           env['id'],
                           sess['id'])
-
-
-class TestSessionsTenantIsolation(base.NegativeTestCase):
-
-    @tag('all', 'coverage')
-    @attr(type='negative')
-    def test_create_session_in_env_from_another_tenant(self):
-        env = self.create_environment('test')
-
-        self.assertRaises(exceptions.Forbidden,
-                          self.alt_client.create_session, env['id'])
-
-    @tag('all', 'coverage')
-    @attr(type='negative')
-    def test_delete_session_in_env_from_another_tenant(self):
-        env = self.create_environment('test')
-        sess = self.client.create_session(env['id'])[1]
-
-        self.assertRaises(exceptions.Forbidden,
-                          self.alt_client.delete_session, env['id'],
-                          sess['id'])
-
-    @tag('all', 'coverage')
-    @attr(type='negative')
-    def test_get_session_in_env_from_another_tenant(self):
-        env = self.create_environment('test')
-        sess = self.client.create_session(env['id'])[1]
-
-        self.assertRaises(exceptions.Forbidden,
-                          self.alt_client.get_session, env['id'],
-                          sess['id'])
-
-    @tag('all', 'coverage')
-    @testtools.skip("https://bugs.launchpad.net/murano/+bug/1382026")
-    @attr(type='negative')
-    def test_deploy_session_in_env_from_another_tenant(self):
-        env = self.create_environment('test')
-        sess = self.client.create_session(env['id'])[1]
-
-        self.assertRaises(exceptions.Forbidden,
-                          self.alt_client.deploy_session, env['id'],
-                          sess['id'])
