@@ -12,15 +12,14 @@
 # limitations under the License.
 
 import fixtures
-from oslo_log import log as logging
+from oslo.config import cfg
 import testtools
 
-from murano.common import config
 from murano.db import api as db_api
+from murano.openstack.common import log
 
-CONF = config.CONF
-logging.register_options(CONF)
-logging.setup(CONF, 'murano')
+CONF = cfg.CONF
+log.setup('murano')
 
 
 class MuranoTestCase(testtools.TestCase):
@@ -41,15 +40,3 @@ class MuranoWithDBTestCase(MuranoTestCase):
         self.override_config('connection', "sqlite://", group='database')
         db_api.setup_db()
         self.addCleanup(db_api.drop_db)
-
-        self.override_config('env_audit_enabled', False, group='stats')
-
-
-class MuranoNotifyWithDBTestCase(MuranoWithDBTestCase):
-
-    def setUp(self):
-        super(MuranoNotifyWithDBTestCase, self).setUp()
-        self.override_config('connection', "sqlite://", group='database')
-        db_api.setup_db()
-        self.addCleanup(db_api.drop_db)
-        self.override_config('env_audit_enabled', True, group='stats')
