@@ -15,7 +15,7 @@
 import types
 
 from testtools import matchers
-from yaql.language import exceptions as yaql_exceptions
+import yaql.exceptions as yaql_exc
 
 from murano.tests.unit.dsl.foundation import object_model as om
 from murano.tests.unit.dsl.foundation import test_case
@@ -62,7 +62,7 @@ class TestEngineYaqlFunctions(test_case.DslTestCase):
             self._runner.testReplaceStr('John Kennedy', 'Kennedy', 'Doe'))
 
         self.assertRaises(
-            yaql_exceptions.NoMatchingMethodException,
+            yaql_exc.YaqlExecutionException,
             self._runner.testReplaceStr, None, 'Kennedy', 'Doe')
 
     def test_replace_dict(self):
@@ -120,7 +120,7 @@ class TestEngineYaqlFunctions(test_case.DslTestCase):
             'false',
             self._runner.testStr(False))
         self.assertEqual(
-            'null',
+            '',
             self._runner.testStr(None))
 
     def test_int(self):
@@ -224,22 +224,3 @@ class TestEngineYaqlFunctions(test_case.DslTestCase):
                 [1, 2, 3, 4, 5, 6, 7, 8],
                 2, 3)
         )
-
-    def test_aggregate(self):
-        self.assertEqual(
-            10,
-            self._runner.testAggregate([1, 2, 3, 4])
-        )
-
-    def test_aggregate_with_initializer(self):
-        self.assertEqual(
-            21,
-            self._runner.testAggregateWithInitializer([1, 2, 3, 4], 11)
-        )
-
-    def test_id(self):
-        obj_id = self._runner.root.object_id
-        self.assertEqual(obj_id * 2, self._runner.testId())
-
-    def test_type(self):
-        self.assertEqual('TestEngineFunctions' * 2, self._runner.testType())
