@@ -23,7 +23,7 @@ class TestPropertyAccess(test_case.DslTestCase):
         self._multi_derived = om.Object(
             'DerivedFrom2Classes',
             rootProperty='ROOT',
-            ambiguousProperty=321)
+            ambiguousProperty2=321)
         model = om.Object(
             'SampleClass3',
             multiClassProperty=self._multi_derived
@@ -41,15 +41,15 @@ class TestPropertyAccess(test_case.DslTestCase):
             exceptions.UninitializedPropertyAccessError,
             self._runner.testUninitializedPrivatePropertyAccess)
         self.assertEqual(
-            'Access to uninitialized property "privateName" '
-            'in class "SampleClass3" is forbidden', str(e))
+            'Access to uninitialized property privateName '
+            'in class SampleClass3 is forbidden', str(e))
 
     def test_read_of_private_property_of_other_class(self):
         e = self.assertRaises(
             exceptions.PropertyAccessError,
             self._runner.testReadOfPrivatePropertyOfOtherClass)
         self.assertEqual(
-            'Property "privateProperty" in class "DerivedFrom2Classes" '
+            'Property privateProperty in class DerivedFrom2Classes '
             'cannot be read', str(e))
         self.assertEqual(['accessing property'], self.traces)
 
@@ -58,22 +58,31 @@ class TestPropertyAccess(test_case.DslTestCase):
             exceptions.PropertyAccessError,
             self._runner.testWriteOfPrivatePropertyOfOtherClass)
         self.assertEqual(
-            'Property "privateProperty" in class "DerivedFrom2Classes" '
+            'Property privateProperty in class DerivedFrom2Classes '
             'cannot be written', str(e))
 
     def test_access_ambiguous_property_with_resolver(self):
         self.assertEqual(
-            '321',
+            321,
             self._runner.on(self._multi_derived).
             testAccessAmbiguousPropertyWithResolver())
 
+    def test_access_ambiguous_property_without_resolver(self):
+        e = self.assertRaises(
+            exceptions.AmbiguousPropertyNameError,
+            self._runner.on(self._multi_derived).
+            testAccessAmbiguousPropertyWithoutResolver)
+        self.assertEqual(
+            'Found more that one property ambiguousProperty1',
+            str(e))
+
     def test_property_merge(self):
         self.assertEqual(
-            '555',
+            555,
             self._runner.on(self._multi_derived).
             testPropertyMerge())
         self.assertEqual(
-            ['321', '555', '555', '555', '555'],
+            [321, 555, 555, '555', 555],
             self.traces)
 
     def test_property_usage(self):
@@ -82,7 +91,7 @@ class TestPropertyAccess(test_case.DslTestCase):
             self._runner.on(self._multi_derived).
             testModifyUsageTestProperty1)
         self.assertEqual(
-            'Property "usageTestProperty1" is immutable to the caller',
+            'Property usageTestProperty1 is immutable to the caller',
             str(e))
         self.assertRaises(
             exceptions.NoWriteAccessError,
@@ -104,7 +113,3 @@ class TestPropertyAccess(test_case.DslTestCase):
             exceptions.NoWriteAccessError,
             self._runner.on(self._multi_derived).
             testModifyUsageTestProperty6)
-        self.assertEqual(
-            77,
-            self._runner.on(
-                self._multi_derived).testModifyUsageTestProperty7())
